package com.ruoyi.system.service;

import com.ruoyi.system.domain.suggestionFj.SuggestionFj;

import java.util.List;
/**
 * 投诉建议_附件Service接口
 * 
 * @author boman
 * @date 2025-02-24
 */
public interface ISuggestionFjService 
{
    /**
     * 查询投诉建议_附件
     * 
     * @param suggestionFjId 投诉建议_附件主键
     * @return 投诉建议_附件
     */
    public SuggestionFj selectSuggestionFjBySuggestionFjId(Long suggestionFjId);

    /**
     * 查询投诉建议_附件列表
     * 
     * @param suggestionFj 投诉建议_附件
     * @return 投诉建议_附件集合
     */
    public List<SuggestionFj> selectSuggestionFjList(SuggestionFj suggestionFj);

    /**
     * 新增投诉建议_附件
     * 
     * @param suggestionFj 投诉建议_附件
     * @return 结果
     */
    public int insertSuggestionFj(SuggestionFj suggestionFj);

    /**
     * 修改投诉建议_附件
     * 
     * @param suggestionFj 投诉建议_附件
     * @return 结果
     */
    public int updateSuggestionFj(SuggestionFj suggestionFj);

    /**
     * 批量删除投诉建议_附件
     * 
     * @param suggestionFjIds 需要删除的投诉建议_附件主键集合
     * @return 结果
     */
    public int deleteSuggestionFjBySuggestionFjIds(Long[] suggestionFjIds);

    /**
     * 删除投诉建议_附件信息
     * 
     * @param suggestionFjId 投诉建议_附件主键
     * @return 结果
     */
    public int deleteSuggestionFjBySuggestionFjId(Long suggestionFjId);
}
